# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFastMarchingImageFilterPython
else:
    import _itkFastMarchingImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkImageRegionPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.ITKFastMarchingBasePython
import itk.itkLevelSetNodePython
import itk.itkNodePairPython
import itk.itkFastMarchingStoppingCriterionBasePython
class itkFastMarchingImageFilterEnums(object):
    r"""Proxy of C++ itkFastMarchingImageFilterEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    Label_FarPoint = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_Label_FarPoint
    
    Label_AlivePoint = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_Label_AlivePoint
    
    Label_TrialPoint = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_Label_TrialPoint
    
    Label_InitialTrialPoint = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_Label_InitialTrialPoint
    
    Label_OutsidePoint = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_Label_OutsidePoint
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkFastMarchingImageFilterEnums
        __init__(self, arg0) -> itkFastMarchingImageFilterEnums

        Parameters
        ----------
        arg0: itkFastMarchingImageFilterEnums const &

        """
        _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_swiginit(self, _itkFastMarchingImageFilterPython.new_itkFastMarchingImageFilterEnums(*args))
    __swig_destroy__ = _itkFastMarchingImageFilterPython.delete_itkFastMarchingImageFilterEnums

# Register itkFastMarchingImageFilterEnums in _itkFastMarchingImageFilterPython:
_itkFastMarchingImageFilterPython.itkFastMarchingImageFilterEnums_swigregister(itkFastMarchingImageFilterEnums)

def itkFastMarchingImageFilterIF2IF2_New():
    return itkFastMarchingImageFilterIF2IF2.New()

class itkFastMarchingImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkFastMarchingImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingImageFilterIF2IF2_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingImageFilterIF2IF2_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_Clone(self)

    def SetOutsidePoints(self, points):
        r"""
        SetOutsidePoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF2 *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOutsidePoints(self, points)

    def SetAlivePoints(self, points):
        r"""
        SetAlivePoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF2 *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetAlivePoints(self, points)

    def GetAlivePoints(self):
        r"""GetAlivePoints(self) -> itkVectorContainerUILSNF2_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetAlivePoints(self)

    def SetTrialPoints(self, points):
        r"""
        SetTrialPoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF2 *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetTrialPoints(self, points)

    def GetTrialPoints(self):
        r"""GetTrialPoints(self) -> itkVectorContainerUILSNF2_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetTrialPoints(self)

    def GetLabelImage(self):
        r"""GetLabelImage(self) -> itk::SmartPointer< itk::Image< itk::FastMarchingImageFilterEnums::Label > >"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetLabelImage(self)

    def SetSpeedConstant(self, value):
        r"""
        SetSpeedConstant(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetSpeedConstant(self, value)

    def GetSpeedConstant(self):
        r"""GetSpeedConstant(self) -> double const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetSpeedConstant(self)

    def SetNormalizationFactor(self, _arg):
        r"""
        SetNormalizationFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetNormalizationFactor(self, _arg)

    def GetNormalizationFactor(self):
        r"""GetNormalizationFactor(self) -> double"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetNormalizationFactor(self)

    def SetStoppingValue(self, _arg):
        r"""
        SetStoppingValue(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetStoppingValue(self, _arg)

    def GetStoppingValue(self):
        r"""GetStoppingValue(self) -> double const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetStoppingValue(self)

    def SetCollectPoints(self, _arg):
        r"""
        SetCollectPoints(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetCollectPoints(self, _arg)

    def GetCollectPoints(self):
        r"""GetCollectPoints(self) -> bool const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetCollectPoints(self)

    def CollectPointsOn(self):
        r"""CollectPointsOn(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_CollectPointsOn(self)

    def CollectPointsOff(self):
        r"""CollectPointsOff(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_CollectPointsOff(self)

    def GetProcessedPoints(self):
        r"""GetProcessedPoints(self) -> itkVectorContainerUILSNF2_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetProcessedPoints(self)

    def SetOutputSize(self, size):
        r"""
        SetOutputSize(self, size)

        Parameters
        ----------
        size: itkSize2 const &

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOutputSize(self, size)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize2"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetOutputSize(self)

    def SetOutputRegion(self, _arg):
        r"""
        SetOutputRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion2

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOutputRegion(self, _arg)

    def GetOutputRegion(self):
        r"""GetOutputRegion(self) -> itkImageRegion2"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetOutputRegion(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetOutputSpacing(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetOutputDirection(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetOutputOrigin(self)

    def SetOverrideOutputInformation(self, _arg):
        r"""
        SetOverrideOutputInformation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SetOverrideOutputInformation(self, _arg)

    def GetOverrideOutputInformation(self):
        r"""GetOverrideOutputInformation(self) -> bool const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_GetOverrideOutputInformation(self)

    def OverrideOutputInformationOn(self):
        r"""OverrideOutputInformationOn(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_OverrideOutputInformationOn(self)

    def OverrideOutputInformationOff(self):
        r"""OverrideOutputInformationOff(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_OverrideOutputInformationOff(self)
    SameDimensionCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SameDimensionCheck
    
    SpeedConvertibleToDoubleCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_SpeedConvertibleToDoubleCheck
    
    DoubleConvertibleToLevelSetCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_DoubleConvertibleToLevelSetCheck
    
    LevelSetOStreamWritableCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_LevelSetOStreamWritableCheck
    
    __swig_destroy__ = _itkFastMarchingImageFilterPython.delete_itkFastMarchingImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingImageFilterIF2IF2

        Create a new object of the class itkFastMarchingImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingImageFilterIF2IF2 in _itkFastMarchingImageFilterPython:
_itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2_swigregister(itkFastMarchingImageFilterIF2IF2)

def itkFastMarchingImageFilterIF3IF3_New():
    return itkFastMarchingImageFilterIF3IF3.New()

class itkFastMarchingImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkFastMarchingImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingImageFilterIF3IF3_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingImageFilterIF3IF3_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_Clone(self)

    def SetOutsidePoints(self, points):
        r"""
        SetOutsidePoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF3 *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOutsidePoints(self, points)

    def SetAlivePoints(self, points):
        r"""
        SetAlivePoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF3 *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetAlivePoints(self, points)

    def GetAlivePoints(self):
        r"""GetAlivePoints(self) -> itkVectorContainerUILSNF3_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetAlivePoints(self)

    def SetTrialPoints(self, points):
        r"""
        SetTrialPoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF3 *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetTrialPoints(self, points)

    def GetTrialPoints(self):
        r"""GetTrialPoints(self) -> itkVectorContainerUILSNF3_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetTrialPoints(self)

    def GetLabelImage(self):
        r"""GetLabelImage(self) -> itk::SmartPointer< itk::Image< itk::FastMarchingImageFilterEnums::Label,3 > >"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetLabelImage(self)

    def SetSpeedConstant(self, value):
        r"""
        SetSpeedConstant(self, value)

        Parameters
        ----------
        value: double

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetSpeedConstant(self, value)

    def GetSpeedConstant(self):
        r"""GetSpeedConstant(self) -> double const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetSpeedConstant(self)

    def SetNormalizationFactor(self, _arg):
        r"""
        SetNormalizationFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetNormalizationFactor(self, _arg)

    def GetNormalizationFactor(self):
        r"""GetNormalizationFactor(self) -> double"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetNormalizationFactor(self)

    def SetStoppingValue(self, _arg):
        r"""
        SetStoppingValue(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetStoppingValue(self, _arg)

    def GetStoppingValue(self):
        r"""GetStoppingValue(self) -> double const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetStoppingValue(self)

    def SetCollectPoints(self, _arg):
        r"""
        SetCollectPoints(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetCollectPoints(self, _arg)

    def GetCollectPoints(self):
        r"""GetCollectPoints(self) -> bool const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetCollectPoints(self)

    def CollectPointsOn(self):
        r"""CollectPointsOn(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_CollectPointsOn(self)

    def CollectPointsOff(self):
        r"""CollectPointsOff(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_CollectPointsOff(self)

    def GetProcessedPoints(self):
        r"""GetProcessedPoints(self) -> itkVectorContainerUILSNF3_Pointer"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetProcessedPoints(self)

    def SetOutputSize(self, size):
        r"""
        SetOutputSize(self, size)

        Parameters
        ----------
        size: itkSize3 const &

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOutputSize(self, size)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize3"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetOutputSize(self)

    def SetOutputRegion(self, _arg):
        r"""
        SetOutputRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion3

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOutputRegion(self, _arg)

    def GetOutputRegion(self):
        r"""GetOutputRegion(self) -> itkImageRegion3"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetOutputRegion(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetOutputSpacing(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetOutputDirection(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetOutputOrigin(self)

    def SetOverrideOutputInformation(self, _arg):
        r"""
        SetOverrideOutputInformation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SetOverrideOutputInformation(self, _arg)

    def GetOverrideOutputInformation(self):
        r"""GetOverrideOutputInformation(self) -> bool const &"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_GetOverrideOutputInformation(self)

    def OverrideOutputInformationOn(self):
        r"""OverrideOutputInformationOn(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_OverrideOutputInformationOn(self)

    def OverrideOutputInformationOff(self):
        r"""OverrideOutputInformationOff(self)"""
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_OverrideOutputInformationOff(self)
    SameDimensionCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SameDimensionCheck
    
    SpeedConvertibleToDoubleCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_SpeedConvertibleToDoubleCheck
    
    DoubleConvertibleToLevelSetCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_DoubleConvertibleToLevelSetCheck
    
    LevelSetOStreamWritableCheck = _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_LevelSetOStreamWritableCheck
    
    __swig_destroy__ = _itkFastMarchingImageFilterPython.delete_itkFastMarchingImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingImageFilterIF3IF3

        Create a new object of the class itkFastMarchingImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingImageFilterIF3IF3 in _itkFastMarchingImageFilterPython:
_itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3_swigregister(itkFastMarchingImageFilterIF3IF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def fast_marching_image_filter(*args: itkt.ImageLike,  outside_points=..., alive_points=..., trial_points=..., speed_constant: float=..., normalization_factor: float=..., stopping_value: float=..., collect_points: bool=..., output_size: Sequence[int]=..., output_region: itkt.ImageRegion=..., output_spacing: Sequence[float]=..., output_direction=..., output_origin: Sequence[float]=..., override_output_information: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for FastMarchingImageFilter"""
    import itk

    kwarg_typehints = { 'outside_points':outside_points,'alive_points':alive_points,'trial_points':trial_points,'speed_constant':speed_constant,'normalization_factor':normalization_factor,'stopping_value':stopping_value,'collect_points':collect_points,'output_size':output_size,'output_region':output_region,'output_spacing':output_spacing,'output_direction':output_direction,'output_origin':output_origin,'override_output_information':override_output_information }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.FastMarchingImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def fast_marching_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKFastMarching.FastMarchingImageFilter
    fast_marching_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    fast_marching_image_filter.__doc__ = filter_object.__doc__



